@@ -7,7 +7,9 @@ use Math ();
 
 #use Exporter;
 
-our $VERSION = '0.314';
+our $VERSION = '0.323';
+
+use base 'Math::Vector';
 
 =head1 NAME
 
@@ -15,7 +17,7 @@ Math::Vec2 - Perl class to represent 2d vectors
 
 =head1 TREE
 
--+- L<Math::Vec2>
+-+- L<Math::Vector> -+- L<Math::Vec2>
 
 =head1 SEE ALSO
 
@@ -36,83 +38,10 @@ L<Math::Color>, L<Math::ColorRGBA>, L<Math::Image>, L<Math::Vec2>, L<Math::Vec3>
 
 	0 0
 
-=cut
-
-use overload
-  '=' => \&copy,
-
-  #"&", "^", "|",
-
-  '~' => sub { $_[0]->new( [ CORE::reverse @{ $_[0] } ] ) },
-
-  '>>' => sub { $_[1] & 1 ? ~$_[0] : $_[0]->copy },
-  '<<' => sub { $_[1] & 1 ? ~$_[0] : $_[0]->copy },
-  '>>=' => sub { @{ $_[0] } = CORE::reverse @{ $_[0] } if $_[1] & 1; $_[0] },
-  '<<=' => sub { @{ $_[0] } = CORE::reverse @{ $_[0] } if $_[1] & 1; $_[0] },
-
-  '<'   => sub { $_[1] > $_[0]->length },
-  '<='  => sub { $_[1] >= $_[0]->length },
-  '>'   => sub { $_[1] < $_[0]->length },
-  '>='  => sub { $_[1] <= $_[0]->length },
-  '<=>' => sub { $_[1] <=> $_[0]->length },
-  '=='  => sub { "$_[0]" eq $_[1] },
-  '!='  => sub { "$_[0]" ne $_[1] },
-
-  'lt'  => sub { $_[1] gt "$_[0]" },
-  'le'  => sub { $_[1] ge "$_[0]" },
-  'gt'  => sub { $_[1] lt "$_[0]" },
-  'ge'  => sub { $_[1] le "$_[0]" },
-  'cmp' => sub { $_[1] cmp "$_[0]" },
-  'eq'  => sub { "$_[0]" eq $_[1] },
-  'ne'  => sub { "$_[0]" ne $_[1] },
-
-  #"!" => sub { !$_[0]->length },
-  'bool' => \&length,
-  '0+'   => \&length,
-
-  'abs' => \&abs,
-  'neg' => \&negate,
-
-  '+='  => \&_add,
-  '-='  => \&_subtract,
-  '*='  => \&_multiply,
-  '/='  => \&_divide,
-  '**=' => \&__pow,
-  '%='  => \&__mod,
-  #".=",
-
-  '+'  => \&add,
-  '-'  => \&subtract,
-  '*'  => \&multiply,
-  '/'  => \&divide,
-  '**' => \&_pow,
-  '%'  => \&_mod,
-  '.'  => \&dot,
-
-  #"x", "x=",
-
-  #"atan2", "cos", "sin", "exp", "log", "sqrt", "int"
-
-  #"<>"
-
-  #'${}', '@{}', '%{}', '&{}', '*{}'.
-
-  #"nomethod", "fallback",
-
-  '""' => \&toString,
-  ;
-
 =head1 OPERATORS
 
 =head2 Summary
 
-	'~'		=>   Returns the reverse of this vector.
-	
-	'>>'		=>   Performs a clockwise rotation of the components.
-	'>>='		=>   Performs a clockwise rotation of the components.
-	'<<'		=>   Performs a counter-clockwise rotation of the components.    
-	'<<='		=>   Performs a counter-clockwise rotation of the components.    
-	
 	'!'		=>   Returns true if the length of this vector is 0
 	
 	'<'		=>   Numerical gt. Compares the length of this vector with a vector or a scalar value.
@@ -156,54 +85,48 @@ use overload
 	
 	'""'		=>   Returns a string representation of the vector.
 
-=head2 ~
-
-Returns the reverse of this vector.
-Very similar to L<perlbuiltin/reverse>.
-
-	my $v = new Math::Vec2(1,2);
-	
-	printf "2 1 = %s\n",  ~$v;  # swap components
-	printf "1 2 = %s\n", ~~$v;
-
-=head2 >>
-
-Performs a clockwise rotation of the components.
-Very similar to bitwise right-shift.
-
-	my $v = new Math::Vec2(1,2);
-	
-	printf "2 1 = %s\n", $v >> 1;
-	printf "1 2 = %s\n", $v >> 2;
-
-=head2 <<
-
-Performs a counter-clockwise rotation of the components.
-Very similar to bitwise left-shift.
-
-	my $v = new Math::Vec2(1,2);
-	
-	printf "2 1 = %s\n", $v << 1;
-	printf "1 2 = %s\n", $v << 2;
-
-=head2 abs()
-
-Performs a componentwise abs.
-This is used to overload the 'abs' operator.
-
-	$v = new Math::Vec2(-4, 5);
-	$v = $vec2->abs;
-	$v = abs($vec2);
-	printf $v;         # 4 5
-
-=head2 **
-
-	$v = $v1 * $v1 * $v1;
-	$v = $v1 ** 3;
-
 =cut
 
-sub abs { $_[0]->new( [ map { CORE::abs($_) } @{ $_[0] } ] ) }
+use overload
+  #"&", "^", "|",
+
+  #'>>' => sub { $_[1] & 1 ? ~$_[0] : $_[0]->copy },
+  #'<<' => sub { $_[1] & 1 ? ~$_[0] : $_[0]->copy },
+  #'>>=' => sub { @{ $_[0] } = CORE::reverse @{ $_[0] } if $_[1] & 1; $_[0] },
+  #'<<=' => sub { @{ $_[0] } = CORE::reverse @{ $_[0] } if $_[1] & 1; $_[0] },
+
+  #"!" => sub { !$_[0]->length },
+  'bool' => \&length,
+  '0+'   => \&length,
+
+  'neg' => \&negate,
+
+  '+='  => \&_add,
+  '-='  => \&_subtract,
+  '*='  => \&_multiply,
+  '/='  => \&_divide,
+  '**=' => \&__pow,
+  '%='  => \&__mod,
+  #".=",
+
+  '+'  => \&add,
+  '-'  => \&subtract,
+  '*'  => \&multiply,
+  '/'  => \&divide,
+  '**' => \&_pow,
+  '%'  => \&_mod,
+  '.'  => \&dot,
+
+  #"x", "x=",
+
+  #"atan2", "cos", "sin", "exp", "log", "sqrt", "int"
+
+  #"<>"
+
+  #'${}', '@{}', '%{}', '&{}', '*{}'.
+
+  #"nomethod", "fallback",
+  ;
 
 =head1 METHODS
 
@@ -220,72 +143,6 @@ Get the default value as array ref
 
 use constant getDefaultValue => [ 0, 0 ];
 
-=head2 new
-
-	my $v = new Math::Vec2; 					  
-	my $v2 = new Math::Vec2(1,2);
-	my @v3 = @$v; 
-	
-If you call new() with a reference to an array, it will be used as reference.
-
-	my $v3 = new Math::Vec2([1,2]); 
-
-=cut
-
-sub new {
-	my $self = shift;
-	my $class = ref($self) || $self;
-
-	if ( 0 == @_ ) {
-		# No arguments, default to standard
-		return bless [ @{ $self->getDefaultValue } ], $class;
-	} elsif ( 1 == @_ ) {
-
-		if ( ref( $_[0] ) eq 'ARRAY' ) {    # [0,1]
-			return bless shift(), $class;
-		} else {
-			warn("Don't understand arguments passed to new()");
-		}
-
-	} elsif ( @_ > 1 ) {    # x,y
-		my $this = bless [], $class;
-		$this->setValue(@_);
-		return $this;
-	} else {
-		warn("Don't understand arguments passed to new()");
-	}
-
-	return;
-}
-
-=head2 copy
-
-Makes a copy
-	
-	$v2 = $v1->copy;
-
-=cut
-
-sub copy { $_[0]->new( [ $_[0]->getValue ] ) }
-
-=head2 setValue(x,y,z)
-
-Sets the value of the vector
-
-	$v1->setValue(1,2);
-
-=cut
-
-sub setValue {
-	my $this = shift;
-
-	@$this = map {
-
-		defined $_[$_] ? $_[$_] : $this->getDefaultValue->[$_]
-
-	  } 0 .. Math::minmax( $#_, $#{ $this->getDefaultValue }, $#{ $this->getDefaultValue } )
-}
-
 =head2 setX(x)
 
 Sets the first value of the vector
@@ -297,7 +154,7 @@ Sets the first value of the vector
 
 =cut
 
-sub setX { $_[0]->[0] = $_[1] }
+sub setX { $_[0]->[0] = $_[1]; return }
 
 =head2 setY(y)
 
@@ -310,19 +167,7 @@ Sets the second value of the vector
 
 =cut
 
-sub setY { $_[0]->[1] = $_[1] }
-
-=head2 getValue
-
-Returns the value of the vector (x, y) as a 2 components array.
-
-	@v = $v1->getValue;
-
-=cut
-
-sub getValue { @{ $_[0] } }
-
-=head2 x
+sub setY { $_[0]->[1] = $_[1]; return }
 
 =head2 getX
 
@@ -334,11 +179,8 @@ Returns the first value of the vector.
 
 =cut
 
-sub x    { $_[0]->[0] }
 sub getX { $_[0]->[0] }
 
-=head2 y
-
 =head2 getY
 
 Returns the second value of the vector.
@@ -349,7 +191,6 @@ Returns the second value of the vector.
 
 =cut
 
-sub y    { $_[0]->[1] }
 sub getY { $_[0]->[1] }
 
 =head2 negate
@@ -588,49 +429,8 @@ sub length {
 
 =cut
 
-sub normalize { $_[0] / $_[0]->length }
-
-=head2 sig
-
-Performs a componentwise sig.
-
-	$v = new Math::Vec2(-4, 5);
-	$v = $vec2->sig;
-	printf $v;         # -1 1
-
-=cut
-
-#sub sig { $_[0]->new( [ map { Math::sig($_) } @{ $_[0] } ] ) }
-sub sig { $_[0]->new( [ map { $_ ? ( $_ < 0 ? -1 : 1 ) : 0 } @{ $_[0] } ] ) }
-
-=head2 sum
-
-Returns the sum of the components.
-
-	$v = new Math::Vec2(-8, 2);
-	$s = $vec2->sum;
-	printf $s;         # -6
-
-=cut
-
 sub sum { $_[0]->[0] + $_[0]->[1] }
 
-=head2 toString
-
-Returns a string representation of the vector. This is used
-to overload the '""' operator, so that vector may be
-freely interpolated in strings.
-
-	my $q = new Math::Vec2(1,2);
-	print $q->toString;                # "1 2"
-	print "$q";                        # "1 2"
-
-=cut
-
-sub toString {
-	return join " ", $_[0]->getValue;
-}
-
 1;
 
 =head1 SEE ALSO
